class EndPoint:
    def __init__(self, model=None):
        self.model = model

    def create(self, sku_id=None, storage_url=None, replica=None,):
        pass

    def get(self, endpoint_id):
        pass

    def list(self):
        pass

    def delete(self, endpoint_id):
        pass
